ICMM recommendation rules
icmm_recommendation_rules.RdData-driven recommendation rules evaluated by
generate_icmm_report: when a KPI or mining-domain traffic
light matches a trigger, the associated recommendation is emitted.
icmm_recommendation_rules.RdData-driven recommendation rules evaluated by
generate_icmm_report: when a KPI or mining-domain traffic
light matches a trigger, the associated recommendation is emitted.