A synthetic but realistic panel dataset of six mine sites (copper, gold, iron ore, coal, zinc, bauxite) across 2019-2024 with production, emissions, energy, water, land, safety, workforce and community fields. Designed for tutorials, tests and the bundled Shiny dashboard. All values are simulated; no real operation is represented.
Format
A data frame with 36 rows (6 sites x 6 years) and 26 variables
including ore_processed_kt, ghg_scope1_t, ghg_scope2_t,
energy_gj, water_withdrawal_m3, water_recycled_m3,
land_disturbed_ha, land_rehabilitated_ha, hours_worked,
recordable_injuries, fatalities, female_employment_pct,
local_employment_pct, revenue_musd, community_investment_musd,
tailings_kt, and waste_rock_kt.
Examples
head(demo_mine_sites)
#> site_id site_name commodity country year ore_processed_kt ghg_scope1_t
#> 1 CU-ATAC Atacama Copper Copper CHL 2019 18481.0 636010
#> 2 CU-ATAC Atacama Copper Copper CHL 2020 18020.1 653331
#> 3 CU-ATAC Atacama Copper Copper CHL 2021 19293.9 651551
#> 4 CU-ATAC Atacama Copper Copper CHL 2022 18580.4 564789
#> 5 CU-ATAC Atacama Copper Copper CHL 2023 18885.5 612173
#> 6 CU-ATAC Atacama Copper Copper CHL 2024 20762.1 640035
#> ghg_scope2_t energy_gj renewable_energy_pct water_withdrawal_m3
#> 1 342467 10449110 5.3 16566110
#> 2 351794 9737005 9.8 16650452
#> 3 350835 10123803 16.7 16692419
#> 4 304117 9744201 19.6 15724091
#> 5 329632 9970955 30.5 18491266
#> 6 344634 9803483 40.1 18178295
#> water_discharge_m3 water_recycled_m3 land_disturbed_ha land_rehabilitated_ha
#> 1 3502640 8144178 260 60.4
#> 2 4405189 8229281 285 85.6
#> 3 3550295 9109240 310 112.1
#> 4 2966083 8464872 335 153.3
#> 5 3414199 11261168 360 173.9
#> 6 4547146 12544016 385 217.6
#> workforce hours_worked recordable_injuries lost_time_injuries fatalities
#> 1 3200 6400000 32 10 0
#> 2 3232 6464000 25 10 0
#> 3 3264 6528000 24 8 0
#> 4 3296 6592000 26 9 0
#> 5 3328 6656000 27 8 0
#> 6 3360 6720000 20 7 0
#> female_employment_pct local_employment_pct revenue_musd
#> 1 10.5 58.6 3348.8
#> 2 10.9 59.0 3265.8
#> 3 14.4 61.3 2746.5
#> 4 18.2 62.7 3153.7
#> 5 19.4 70.8 3445.4
#> 6 21.1 66.2 3658.0
#> community_investment_musd tailings_kt waste_rock_kt
#> 1 23.96 17750.0 45411.5
#> 2 26.77 17693.7 51285.8
#> 3 22.28 18496.7 46648.5
#> 4 26.14 18177.2 46480.9
#> 5 44.20 17632.6 49556.3
#> 6 37.09 20406.0 55605.0